@@ -104,7 +104,6 @@ class PerturbFlow(nn.Module):
         #self.use_bias = not zero_bias
         
         self.codebook_weights = None
-        self.total_count = None
 
         set_random_seed(seed)
         self.setup_networks()
@@ -318,7 +317,6 @@ class PerturbFlow(nn.Module):
         if self.loss_func=='negbinomial':
             total_count = pyro.param("inverse_dispersion", self.inverse_dispersion *
                                      xs.new_ones(self.input_size), constraint=constraints.positive)
-            self.total_count = total_count
             
         if self.use_zeroinflate:
             gate_logits = pyro.param("dropout_rate", xs.new_zeros(self.input_size))
@@ -398,7 +396,6 @@ class PerturbFlow(nn.Module):
         if self.loss_func=='negbinomial':
             total_count = pyro.param("inverse_dispersion", self.inverse_dispersion *
                                      xs.new_ones(self.input_size), constraint=constraints.positive)
-            self.total_count = total_count
             
         if self.use_zeroinflate:
             gate_logits = pyro.param("dropout_rate", xs.new_zeros(self.input_size))
@@ -483,7 +480,6 @@ class PerturbFlow(nn.Module):
         if self.loss_func=='negbinomial':
             total_count = pyro.param("inverse_dispersion", self.inverse_dispersion *
                                      xs.new_ones(self.input_size), constraint=constraints.positive)
-            self.total_count = total_count
             
         if self.use_zeroinflate:
             gate_logits = pyro.param("dropout_rate", xs.new_zeros(self.input_size))
@@ -580,7 +576,6 @@ class PerturbFlow(nn.Module):
         if self.loss_func=='negbinomial':
             total_count = pyro.param("inverse_dispersion", self.inverse_dispersion *
                                      xs.new_ones(self.input_size), constraint=constraints.positive)
-            self.total_count = total_count
             
         if self.use_zeroinflate:
             gate_logits = pyro.param("dropout_rate", xs.new_zeros(self.input_size))
@@ -1065,9 +1060,6 @@ class PerturbFlow(nn.Module):
                 pbar.set_postfix({'loss': str_loss})
                 pbar.update(1)
                 
-        if self.loss_func == 'negbinomial':
-            self.total_count = pyro.param('inverse_dispersion')
-
     @classmethod
     def save_model(cls, model, file_path, compression=False):
         """Save the model to the specified file path."""
